![SuperTokens banner](https://raw.githubusercontent.com/supertokens/supertokens-logo/master/images/Artboard%20%E2%80%93%2027%402x.png)

# SuperTokens Python SDK

<a href="https://supertokens.com/discord">
<img src="https://img.shields.io/discord/603466164219281420.svg?logo=discord"
    alt="chat on Discord"></a>
<a href="https://pypi.org/project/supertokens-python">
<img alt="Last 30 days downloads for supertokens-python" src="https://pepy.tech/badge/supertokens-python/month"/>
</a>

## About
This is a Python library that is used to interface between a python API process and the SuperTokens http service.

Learn more at https://supertokens.com

## Documentation

To see documentation, please click [here](https://supertokens.com/docs/community/introduction).

## Contributing

Please see the [CONTRIBUTING.md](https://github.com/supertokens/supertokens-python/blob/master/CONTRIBUTING.md) file for instructions.

## Contact us

For any queries, or support requests, please email us at team@supertokens.io, or join our [Discord](https://supertokens.com/discord) server.

## Authors

Created with :heart: by the folks at SuperTokens.io.